Skip to main contentCrate egui_table_kit
Source - delegate
- error
- filter
- Combined table filters.
- header
- Layout and options structures for column header interaction overlays.
- highlights
- Highlighting layers powered by roaring bitmaps.
- layout
- Table viewer for egui.
- operations
- Table management actions and toolbar operations frameworks.
- state
- Custom interactive view states mapped seamlessly to virtualization targets.
- table
- High-level table runner to completely encapsulate
egui_table and Delegate boilerplate.
- CHARSET
- A deterministically sorted string containing all unique characters
used across all
.ftl files in this crate and its dependencies.
- CACHE
- LOCALES