pub struct TableKitDelegate<'a> {Show 19 fields
pub provider: &'a dyn TableProvider,
pub state: &'a mut TableState,
pub org_colors: &'a [[u8; 3]],
pub user_colors: &'a [[u8; 3]],
pub collected_responses: &'a mut Vec<ColResponse>,
pub halt_error: &'a mut Option<TableError>,
pub custom_cell_ui: Option<Box<CustomCellCallback<'a>>>,
pub item_clicked: &'a mut Option<usize>,
pub secondary_clicked: &'a mut Option<usize>,
pub is_new_pass: bool,
pub cell_padding: Margin,
pub highlight_entire_row: bool,
pub hovered_row: Option<u64>,
pub header_menu_anchor: HeaderMenuAnchor,
pub row_height: f32,
pub header_bg_color: Option<Color32>,
pub striped: bool,
pub striping_color: Option<Color32>,
pub hover_color: Option<Color32>,
}Expand description
The central delegate translating kit properties to the underlying egui_table layout.
Fields
provider: &'a dyn TableProviderstate: &'a mut TableStateorg_colors: &'a [[u8; 3]]user_colors: &'a [[u8; 3]]collected_responses: &'a mut Vec<ColResponse>halt_error: &'a mut Option<TableError>custom_cell_ui: Option<Box<CustomCellCallback<'a>>>item_clicked: &'a mut Option<usize>secondary_clicked: &'a mut Option<usize>is_new_pass: boolcell_padding: Marginhighlight_entire_row: boolhovered_row: Option<u64>row_height: f32header_bg_color: Option<Color32>striped: boolstriping_color: Option<Color32>hover_color: Option<Color32>Implementations
Sourceimpl<'a> TableKitDelegate<'a>
impl<'a> TableKitDelegate<'a>
Sourcepub fn new(
provider: &'a dyn TableProvider,
state: &'a mut TableState,
org_colors: &'a [[u8; 3]],
user_colors: &'a [[u8; 3]],
collected_responses: &'a mut Vec<ColResponse>,
halt_error: &'a mut Option<TableError>,
custom_cell_ui: Option<Box<CustomCellCallback<'a>>>,
item_clicked: &'a mut Option<usize>,
secondary_clicked: &'a mut Option<usize>,
) -> Self
pub fn new( provider: &'a dyn TableProvider, state: &'a mut TableState, org_colors: &'a [[u8; 3]], user_colors: &'a [[u8; 3]], collected_responses: &'a mut Vec<ColResponse>, halt_error: &'a mut Option<TableError>, custom_cell_ui: Option<Box<CustomCellCallback<'a>>>, item_clicked: &'a mut Option<usize>, secondary_clicked: &'a mut Option<usize>, ) -> Self
Creates a new delegate instance with robust visual defaults.