Module filter

Module filter 

Combined table filters.

Modules

highlight
Color highlight options and layout configuration widgets.
search
Search matching structures with support for Regex and case-insensitive lookups.

Structs

Filter
Composable filter containing text matching query criteria and row highlight restrictions.