pub struct Highlights(pub [RoaringBitmap; 10]);Expand description
Highlighting structure mapping row indices to one of up to 10 color-tag groups.
Tuple Fields
0: [RoaringBitmap; 10]Implementations
Sourceimpl Highlights
impl Highlights
Sourcepub fn get_usize(&self, index: usize) -> Option<u8>
pub fn get_usize(&self, index: usize) -> Option<u8>
Accesses the highlight color index assigned to the row (if any).
Sourcepub fn insert(&mut self, typ: u8, index: u32) -> bool
pub fn insert(&mut self, typ: u8, index: u32) -> bool
Adds a row index to a specific highlight color group.
Sourcepub fn get(&self, index: u32) -> Option<u8>
pub fn get(&self, index: u32) -> Option<u8>
Accesses the highlight color group index matching a specific row index.
Sourcepub fn insert_map(&mut self, typ: u8, map: &RoaringBitmap)
pub fn insert_map(&mut self, typ: u8, map: &RoaringBitmap)
Unions a selection map into a specific highlight group, removing them from other groups.
Sourcepub fn remove_map(&mut self, map: &RoaringBitmap)
pub fn remove_map(&mut self, map: &RoaringBitmap)
Removes a collection of row indices from all color highlight groups.