pub struct Column {
pub current: f32,
pub range: Rangef,
pub id: Option<Id>,
pub flags: ColumnFlags,
}Fields
current: f32range: Rangefid: Option<Id>flags: ColumnFlagsImplementations
Sourceimpl Column
impl Column
Sourcepub fn auto_size_this_frame(self, auto_size_this_frame: bool) -> Self
pub fn auto_size_this_frame(self, auto_size_this_frame: bool) -> Self
If set, the column will be automatically sized based on the content this frame.
Sourcepub fn auto_fit(self, auto_fit: bool) -> Self
pub fn auto_fit(self, auto_fit: bool) -> Self
Set whether the column should auto-fit to content width on first load.
Sourcepub fn remainder(self, remainder: bool) -> Self
pub fn remainder(self, remainder: bool) -> Self
Set whether the column should absorb remaining horizontal space on layout passes.
Sourcepub const fn is_resizable(&self) -> bool
pub const fn is_resizable(&self) -> bool
Getter for whether the column is resizable.
Sourcepub const fn is_auto_size_this_frame(&self) -> bool
pub const fn is_auto_size_this_frame(&self) -> bool
Getter for whether the column should auto-size this frame.
Sourcepub const fn is_auto_fit(&self) -> bool
pub const fn is_auto_fit(&self) -> bool
Getter for whether the column should auto-fit.
Sourcepub const fn is_remainder(&self) -> bool
pub const fn is_remainder(&self) -> bool
Getter for whether the column acts as a remainder.
pub fn id_for(&self, col_idx: usize) -> Id