#[non_exhaustive]pub struct PrefetchInfo {
pub num_sticky_columns: usize,
pub visible_columns: Range<usize>,
pub visible_rows: Range<u64>,
pub table_id: Id,
}Expand description
Data given to the delegate containing information about what is about to be rendered.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.num_sticky_columns: usizeThe sticky columns are always visible.
visible_columns: Range<usize>This range of columns are currently visible, in addition to the sticky ones.
visible_rows: Range<u64>These rows are currently visible.
table_id: IdThe unique Id of this table.