SplitScroll

Struct SplitScroll 

pub struct SplitScroll {
    pub scroll_enabled: Vec2b,
    pub fixed_size: Vec2,
    pub scroll_outer_size: Vec2,
    pub scroll_content_size: Vec2,
    pub stick_to_bottom: bool,
}
A scroll area with some portion of its left and/or top side “stuck”.

This produces four quadrants:

              <-------LEFT-------> <---------RIGHT---------->

             ------------------------------------------------
         ^   |                    |   <----------------->   |
   TOP   |   |       Fixed        |      Horizontally       |
         V   |    fixed_size      |       scrollable        |
             |--------------------|-------------------------|.................
         ^   | ^                  |           ^             |                .
 BOTTOM  |   | |   Vertically     | <-  Fully scrollable -> |                .
         |   | |   scrollable     |    scroll_outer_size    |                .
         V   | v                  |           v             |                .
             |____________________|_________________________|                .
                                  .                                          .
                                  .                   scroll_content_size    .
                                  .                                          .
                                  ............................................

The above shows the initial layout when the scroll offset is zero (no scrolling has occurred yet).

Fields

scroll_enabled: Vec2bfixed_size: Vec2

Width of the fixed left side, and height of the fixed top.

scroll_outer_size: Vec2

Size of the small container of the right bottom scrollable region.

scroll_content_size: Vec2

Size of the large contents of the right bottom region, ignoring the left/top fixed regions.

stick_to_bottom: bool

If true, the vertical scrollbar will stick to the bottom as the content grows.

Implementations

Source

impl SplitScroll

pub fn show(self, ui: &mut Ui, delegate: &mut dyn SplitScrollDelegate)