RowCallback

Type Alias RowCallback 

pub type RowCallback<'b> = dyn FnMut(&dyn Row) -> Result<(), TableError> + 'b;
The callback signature used to process streamed row data.

  • 'b represents the lifetime of any local variables captured by the closure.