TableKit

Struct TableKit 

pub struct TableKit<'a> { /* private fields */ }

Implementations

Source

impl<'a> TableKit<'a>

pub fn new( id: impl Into<String>, provider: &'a dyn TableProvider, state: &'a mut TableState, ) -> Self

pub fn with_columns(self, columns: Vec<Column>) -> Self

pub const fn with_row_height(self, height: f32) -> Self

pub const fn with_max_height(self, max_height: Option<f32>) -> Self

pub const fn with_colors(self, org: &'a [[u8; 3]], user: &'a [[u8; 3]]) -> Self

pub const fn with_auto_size_mode(self, mode: AutoSizeMode) -> Self

pub const fn with_max_rows(self, max_rows: u64) -> Self

pub const fn with_scroll_to_row(self, row_nr: u64, align: Align) -> Self

Set an optional row to scroll to during the next rendering pass.

pub const fn with_striped(self, striped: bool) -> Self

Enable or disable alternating row background colors.

pub const fn with_striping_color(self, color: Color32) -> Self

Provide a custom background color for alternating striped rows. If none is provided, it falls back to ui.visuals().faint_bg_color.

pub const fn with_hover_color(self, color: Color32) -> Self

Set an optional custom background overlay color for hovered rows.

pub fn show<F>( self, ui: &mut Ui, custom_cell_ui: F, ) -> Result<Response, TableError>
where F: FnMut(&mut Ui, &CellInfo, &dyn Row, Color32) -> Option<Response> + 'a,