Module delegate
egui_
table_
kit
0.5.5
Module delegate
Module Items
Structs
Type Aliases
In crate egui_
table_
kit
egui_table_kit
Module
delegate
Structs

Table
KitDelegate
The central delegate translating kit properties to the underlying
egui_table
layout.
Type Aliases

Custom
Cell
Callback
Shared callback definition used to render custom interactive cellular components.