TableOperations

Struct TableOperations 

pub struct TableOperations(pub Vec<Vec<Box<dyn TableOperation>>>);

Tuple Fields

0: Vec<Vec<Box<dyn TableOperation>>>

Implementations

Source

impl TableOperations

pub fn new() -> Self

pub fn with_group(self, group: Vec<Box<dyn TableOperation>>) -> Self

pub fn with_operation(self, op: impl TableOperation + 'static) -> Self

pub fn gui( &mut self, ui: &mut Ui, provider: &dyn TableProvider, data: &mut TableState, context_menu: bool, ) -> Result<bool, TableError>

Renders standard table operation buttons with default look.

pub fn gui_custom<F>( &mut self, ui: &mut Ui, provider: &dyn TableProvider, data: &mut TableState, context_menu: bool, button_renderer: F, ) -> Result<bool, TableError>
where F: FnMut(&mut Ui, &mut Box<dyn TableOperation>, bool, &str, bool) -> Response,

Renders table operations using a custom button builder callback.

This handles all the state machine details (polling, execution, pending modes, group separation) but allows full control over the visual presentation of each button.