pub struct TableOperations(pub Vec<Vec<Box<dyn TableOperation>>>);Tuple Fields
0: Vec<Vec<Box<dyn TableOperation>>>Implementations
Sourceimpl TableOperations
impl TableOperations
pub fn new() -> Self
pub fn with_group(self, group: Vec<Box<dyn TableOperation>>) -> Self
pub fn with_operation(self, op: impl TableOperation + 'static) -> Self
Sourcepub fn gui(
&mut self,
ui: &mut Ui,
provider: &dyn TableProvider,
data: &mut TableState,
context_menu: bool,
) -> Result<bool, TableError>
pub fn gui( &mut self, ui: &mut Ui, provider: &dyn TableProvider, data: &mut TableState, context_menu: bool, ) -> Result<bool, TableError>
Renders standard table operation buttons with default look.
Sourcepub fn gui_custom<F>(
&mut self,
ui: &mut Ui,
provider: &dyn TableProvider,
data: &mut TableState,
context_menu: bool,
button_renderer: F,
) -> Result<bool, TableError>
pub fn gui_custom<F>( &mut self, ui: &mut Ui, provider: &dyn TableProvider, data: &mut TableState, context_menu: bool, button_renderer: F, ) -> Result<bool, TableError>
Renders table operations using a custom button builder callback.
This handles all the state machine details (polling, execution, pending modes, group separation) but allows full control over the visual presentation of each button.