RowSliceExt

Trait RowSliceExt 

pub trait RowSliceExt {
    // Required methods
    fn get_primary(&self, col_index: usize) -> Result<&str, TableError>;
    fn get_hover(&self, col_index: usize) -> Result<&str, TableError>;
    fn parse_primary<T>(&self, col_index: usize) -> Result<T, TableError>
       where T: FromStr,
             <T as FromStr>::Err: Display;
    fn parse_hover<T>(&self, col_index: usize) -> Result<T, TableError>
       where T: FromStr,
             <T as FromStr>::Err: Display;
}

Required Methods

fn get_primary(&self, col_index: usize) -> Result<&str, TableError>

Extracts the primary text at the specified column index.

fn get_hover(&self, col_index: usize) -> Result<&str, TableError>

Extracts the hover/alternate text at the specified column index.

fn parse_primary<T>(&self, col_index: usize) -> Result<T, TableError>
where T: FromStr, <T as FromStr>::Err: Display,

Parses the primary text at the specified column index into type T.

fn parse_hover<T>(&self, col_index: usize) -> Result<T, TableError>
where T: FromStr, <T as FromStr>::Err: Display,

Parses the hover text at the specified column index into type T.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl RowSliceExt for RowSlice<'_, '_>