pub type RowCallback<'b> = dyn for<'a, 'c> FnMut(RowSlice<'a, 'c>) -> Result<(), TableError> + 'b;Expand description
The callback signature used to process streamed row data.
'brepresents the lifetime of any local variables captured by the closure.for<'a, 'c>unifies the string content lifetime'aand reference lifetime'c, allowing the callback to process rows with short-lived, local lifetimes.