RowCallback

Type Alias RowCallback 

pub type RowCallback<'b> = dyn for<'a, 'c> FnMut(RowSlice<'a, 'c>) -> Result<(), TableError> + 'b;
The callback signature used to process streamed row data.

  • 'b represents the lifetime of any local variables captured by the closure.
  • for<'a, 'c> unifies the string content lifetime 'a and reference lifetime 'c, allowing the callback to process rows with short-lived, local lifetimes.